@@ -9,7 +9,7 @@ use HTTP::Request::Common qw(POST);
 use LWP::UserAgent;
 
 use vars qw/$VERSION/;
-$VERSION = '1.2.0';
+$VERSION = '1.1';
 
 sub new {
     my $class = shift;
@@ -20,7 +20,7 @@ sub reqTemplate {
     my $self = shift;
     my %args = @_;
 
-    my $url = 'https://cloudns.duowan.com/v1.2/api/';
+    my $url = 'https://cloudns.duowan.com/api/';
     my $ua = LWP::UserAgent->new;
     $ua->timeout(30);
     $ua->ssl_opts(verify_hostname => 0);
@@ -29,7 +29,7 @@ sub reqTemplate {
     my $res = $ua->request($req);
 
     if ($res->is_success ) {
-        return from_json( $res->decoded_content );
+        return decode_json($res->decoded_content);
     } else {
         croak $res->status_line;
     }
