@@ -8,7 +8,7 @@ use JSON;
 use base 'Net::Duowan::DNS::Common';
 
 use vars qw/$VERSION/;
-$VERSION = '1.2.0';
+$VERSION = '1.1';
 
 sub new {
     my $class = shift;
@@ -35,7 +35,7 @@ sub fetchMulti {
 
     my %args = @_;
     my $offset = $args{offset} || 0;
-    my $number = $args{number} || 100;
+    my $number = $args{number} || -1;
     my $psp = $self->{psp};
     my $token = $self->{token};
     my $act = 'rec_load_all';
@@ -123,7 +123,7 @@ sub bulkCreate {
     unless (ref $records) {
         croak "records must be an array reference";
     }
-    $records = to_json($records);
+    $records = encode_json($records);
 
     my $psp = $self->{psp};
     my $token = $self->{token};
@@ -173,10 +173,8 @@ sub search {
     my $key = $args{keyword} || croak "no keyword provided";
     my $psp = $self->{psp};
     my $token = $self->{token};
-    my $offset = $args{offset} || 0;
-    my $number = $args{number} || -1;
     my $act = 'rec_search';
-    my %reqs = (a=>$act, z=>$zone, k=>$key, psp=>$psp, tkn=>$token, offset=>$offset, number=>$number);
+    my %reqs = (a=>$act, z=>$zone, k=>$key, psp=>$psp, tkn=>$token);
 
     return $self->reqTemplate(%reqs);
 }
@@ -189,10 +187,8 @@ sub fetchbyHost {
     my $name = $args{name} || "";
     my $psp = $self->{psp};
     my $token = $self->{token};
-    my $offset = $args{offset} || 0;
-    my $number = $args{number} || -1;
     my $act = 'rec_load_by_name';
-    my %reqs = (a=>$act, z=>$zone, name=>$name, psp=>$psp, tkn=>$token, offset=>$offset, number=>$number);
+    my %reqs = (a=>$act, z=>$zone, name=>$name, psp=>$psp, tkn=>$token);
 
     return $self->reqTemplate(%reqs);
 }
@@ -205,10 +201,8 @@ sub fetchbyPrefix {
     my $prefix = $args{prefix} || croak "no record prefix provided";
     my $psp = $self->{psp};
     my $token = $self->{token};
-    my $offset = $args{offset} || 0;
-    my $number = $args{number} || -1;
     my $act = 'rec_load_by_prefix';
-    my %reqs = (a=>$act, z=>$zone, name=>$prefix, psp=>$psp, tkn=>$token, offset=>$offset, number=>$number);
+    my %reqs = (a=>$act, z=>$zone, name=>$prefix, psp=>$psp, tkn=>$token);
 
     return $self->reqTemplate(%reqs);
 }
